Installation
============

To install :mod:`audplot` run:

.. code-block:: bash

    $ # Create and activate Python virtual environment, e.g.
    $ # virtualenv --no-download --python=python3 ${HOME}/.envs/audplot
    $ # source ${HOME}/.envs/audplot/bin/activate
    $ pip install audplot
